@@ -26,12 +26,8 @@ class IconvTest extends TestCase
      */
     public function testIconv()
     {
-        // Native iconv() behavior varies between versions and OS for these two tests
-        // See e.g. https://bugs.php.net/52211
-        if (\PHP_VERSION_ID >= 50610) {
-            $this->assertFalse(@iconv('UTF-8', 'ISO-8859-1', 'nœud'));
-            $this->assertSame('nud', iconv('UTF-8', 'ISO-8859-1//IGNORE', 'nœud'));
-        }
+        $this->assertFalse(@iconv('UTF-8', 'ISO-8859-1', 'nœud'));
+        $this->assertSame('nud', iconv('UTF-8', 'ISO-8859-1//IGNORE', 'nœud'));
 
         $this->assertSame(utf8_decode('déjà'), iconv('CP1252', 'ISO-8859-1', utf8_decode('déjà')));
         $this->assertSame('deja noeud', p::iconv('UTF-8//ignore//IGNORE', 'US-ASCII//TRANSLIT//IGNORE//translit', 'déjà nœud'));
@@ -74,18 +70,42 @@ class IconvTest extends TestCase
         $this->assertSame('x', iconv_substr('x', 0, 1, 'UTF-8'));
     }
 
+    /**
+     * @covers \Symfony\Polyfill\Iconv\Iconv::iconv_substr
+     * @requires PHP < 8
+     */
+    public function testIconvSubstrReturnsFalsePrePHP8()
+    {
+        $c = 'déjà';
+        $this->assertFalse(iconv_substr($c, 42, 1, 'UTF-8'));
+        $this->assertFalse(iconv_substr($c, -42, 1));
+        $this->assertFalse(iconv_substr($c, 42, 26));
+    }
+
+    /**
+     * @covers \Symfony\Polyfill\Iconv\Iconv::iconv_substr
+     * @requires PHP 8
+     */
+    public function testIconvSubstrReturnsEmptyPostPHP8()
+    {
+        $c = 'déjà';
+        $this->assertSame('', iconv_substr($c, 42, 1, 'UTF-8'));
+        $this->assertSame('d', iconv_substr($c, -42, 1));
+        $this->assertSame('', iconv_substr($c, 42, 26));
+    }
+
     /**
      * @covers \Symfony\Polyfill\Iconv\Iconv::iconv_mime_encode
      */
     public function testIconvMimeEncode()
     {
         $text = "\xE3\x83\x86\xE3\x82\xB9\xE3\x83\x88\xE3\x83\x86\xE3\x82\xB9\xE3\x83\x88";
-        $options = array(
+        $options = [
             'scheme' => 'Q',
             'input-charset' => 'UTF-8',
             'output-charset' => 'UTF-8',
             'line-length' => 30,
-        );
+        ];
 
         $this->assertSame(
             "Subject: =?UTF-8?Q?=E3=83=86?=\r\n =?UTF-8?Q?=E3=82=B9?=\r\n =?UTF-8?Q?=E3=83=88?=\r\n =?UTF-8?Q?=E3=83=86?=\r\n =?UTF-8?Q?=E3=82=B9?=\r\n =?UTF-8?Q?=E3=83=88?=",
@@ -101,8 +121,8 @@ class IconvTest extends TestCase
         $this->assertSame('Legal encoded-word: * .', iconv_mime_decode('Legal encoded-word: =?utf-8?B?Kg==?= .'));
         $this->assertSame('Legal encoded-word: * .', iconv_mime_decode('Legal encoded-word: =?utf-8?Q?*?= .'));
         if ('\\' !== \DIRECTORY_SEPARATOR) {
-            $this->assertSame('Illegal encoded-word:  .', iconv_mime_decode('Illegal encoded-word: =?utf-8?Q??= .', ICONV_MIME_DECODE_CONTINUE_ON_ERROR));
-            $this->assertSame('Illegal encoded-word: .', iconv_mime_decode('Illegal encoded-word: =?utf-8?Q?'.\chr(0xA1).'?= .', ICONV_MIME_DECODE_CONTINUE_ON_ERROR));
+            $this->assertSame('Illegal encoded-word:  .', iconv_mime_decode('Illegal encoded-word: =?utf-8?Q??= .', \ICONV_MIME_DECODE_CONTINUE_ON_ERROR));
+            $this->assertSame('Illegal encoded-word: .', iconv_mime_decode('Illegal encoded-word: =?utf-8?Q?'.\chr(0xA1).'?= .', \ICONV_MIME_DECODE_CONTINUE_ON_ERROR));
         }
     }
 
@@ -112,7 +132,8 @@ class IconvTest extends TestCase
     public function testIconvMimeDecodeIllegal()
     {
         iconv_mime_decode('Legal encoded-word: =?utf-8?Q?*?= .');
-        $this->setExpectedException('PHPUnit\Framework\Error\Notice', 'Detected an illegal character in input string');
+        $this->expectNotice();
+        $this->expectNoticeMessage('Detected an illegal character in input string');
         iconv_mime_decode('Illegal encoded-word: =?utf-8?Q?'.\chr(0xA1).'?= .');
     }
 
@@ -130,17 +151,17 @@ X-Bar: =?cp949?B?UkU6odk=?= =?UTF-8?Q?Bar?=
 To: <test@example.com>
 HEADERS;
 
-        $result = array(
+        $result = [
             'From' => '<foo@example.com>',
             'Subject' => '=?ks_c_5601-1987?B?UkU6odk=?= Foo',
-            'X-Bar' => array(
+            'X-Bar' => [
                 'RE:☆ Foo',
                 'RE:☆Bar',
-            ),
+            ],
             'To' => '<test@example.com>',
-        );
+        ];
 
-        $this->assertSame($result, iconv_mime_decode_headers($headers, ICONV_MIME_DECODE_CONTINUE_ON_ERROR, 'UTF-8'));
+        $this->assertSame($result, iconv_mime_decode_headers($headers, \ICONV_MIME_DECODE_CONTINUE_ON_ERROR, 'UTF-8'));
     }
 
     /**
@@ -150,11 +171,11 @@ HEADERS;
      */
     public function testIconvGetEncoding()
     {
-        $a = array(
+        $a = [
            'input_encoding' => 'UTF-8',
            'output_encoding' => 'UTF-8',
            'internal_encoding' => 'UTF-8',
-        );
+        ];
 
         foreach ($a as $t => $e) {
             $this->assertTrue(@iconv_set_encoding($t, $e));
@@ -165,17 +186,4 @@ HEADERS;
 
         $this->assertFalse(@iconv_set_encoding('foo', 'UTF-8'));
     }
-
-    public function setExpectedException($exception, $message = '', $code = null)
-    {
-        if (!class_exists('PHPUnit\Framework\Error\Notice')) {
-            $exception = str_replace('PHPUnit\\Framework\\Error\\', 'PHPUnit_Framework_Error_', $exception);
-        }
-        if (method_exists($this, 'expectException')) {
-            $this->expectException($exception);
-            $this->expectExceptionMessage($message);
-        } else {
-            parent::setExpectedException($exception, $message, $code);
-        }
-    }
 }
