@@ -27,8 +27,15 @@ class GraphemeTest extends TestCase
     public function testGraphemeExtractArrayError()
     {
         grapheme_extract('', 0);
-        $this->setExpectedException('PHPUnit\Framework\Error\Warning', 'expects parameter 1 to be string, array given');
-        grapheme_extract(array(), 0);
+        if (80000 > \PHP_VERSION_ID) {
+            $this->assertFalse(@grapheme_extract([], 0));
+
+            $this->expectWarning();
+            $this->expectWarningMessage('expects parameter 1 to be string, array given');
+        } else {
+            $this->expectException(\TypeError::class);
+        }
+        grapheme_extract([], 0);
     }
 
     /**
@@ -36,39 +43,45 @@ class GraphemeTest extends TestCase
      */
     public function testGraphemeExtract()
     {
-        $this->assertFalse(grapheme_extract('abc', 1, -1));
+        $this->assertFalse(grapheme_extract('', 0));
+        $this->assertSame('', grapheme_extract('abc', 0));
 
-        $this->assertSame(grapheme_extract('', 0), grapheme_extract('', 0));
-        $this->assertSame(grapheme_extract('abc', 0), grapheme_extract('abc', 0));
-
-        $this->assertSame('국어', grapheme_extract('한국어', 2, GRAPHEME_EXTR_COUNT, 3, $next));
+        $this->assertSame('국어', grapheme_extract('한국어', 2, \GRAPHEME_EXTR_COUNT, 3, $next));
         $this->assertSame(9, $next);
 
         $next = 0;
-        $this->assertSame('한', grapheme_extract('한국어', 1, GRAPHEME_EXTR_COUNT, $next, $next));
-        $this->assertSame('국', grapheme_extract('한국어', 1, GRAPHEME_EXTR_COUNT, $next, $next));
-        $this->assertSame('어', grapheme_extract('한국어', 1, GRAPHEME_EXTR_COUNT, $next, $next));
-        $this->assertFalse(grapheme_extract('한국어', 1, GRAPHEME_EXTR_COUNT, $next, $next));
+        $this->assertSame('한', grapheme_extract('한국어', 1, \GRAPHEME_EXTR_COUNT, $next, $next));
+        $this->assertSame('국', grapheme_extract('한국어', 1, \GRAPHEME_EXTR_COUNT, $next, $next));
+        $this->assertSame('어', grapheme_extract('한국어', 1, \GRAPHEME_EXTR_COUNT, $next, $next));
+        $this->assertFalse(grapheme_extract('한국어', 1, \GRAPHEME_EXTR_COUNT, $next, $next));
 
-        $this->assertSame(str_repeat('-', 69000), grapheme_extract(str_repeat('-', 70000), 69000, GRAPHEME_EXTR_COUNT));
+        $this->assertSame(str_repeat('-', 69000), grapheme_extract(str_repeat('-', 70000), 69000, \GRAPHEME_EXTR_COUNT));
 
-        $this->assertSame('d', grapheme_extract('déjà', 2, GRAPHEME_EXTR_MAXBYTES));
-        $this->assertSame('dé', grapheme_extract('déjà', 2, GRAPHEME_EXTR_MAXCHARS));
+        $this->assertSame('d', grapheme_extract('déjà', 2, \GRAPHEME_EXTR_MAXBYTES));
+        $this->assertSame('dé', grapheme_extract('déjà', 2, \GRAPHEME_EXTR_MAXCHARS));
+    }
 
-        $this->assertFalse(@grapheme_extract(array(), 0));
-        $this->assertFalse(@grapheme_extract(array(), 0));
+    /**
+     * @covers \Symfony\Polyfill\Intl\Grapheme\Grapheme::grapheme_extract
+     */
+    public function testGraphemeExtractWithInvalidType()
+    {
+        if (80000 <= \PHP_VERSION_ID) {
+            $this->expectException(\ValueError::class);
+            $this->expectExceptionMessage('grapheme_extract(): Argument #3 ($type) must be one of GRAPHEME_EXTR_COUNT, GRAPHEME_EXTR_MAXBYTES, or GRAPHEME_EXTR_MAXCHARS');
+        }
+
+        $this->assertFalse(grapheme_extract('abc', 1, -1));
     }
 
     /**
-     * @requires PHP 7.1
-     *
      * @covers \Symfony\Polyfill\Intl\Grapheme\Grapheme::grapheme_extract
      */
     public function testGraphemeExtractWithNegativeStart()
     {
-        $this->assertSame('j', grapheme_extract('déjà', 2, GRAPHEME_EXTR_MAXBYTES, -3, $next));
+        $this->assertSame('j', grapheme_extract('déjà', 2, \GRAPHEME_EXTR_MAXBYTES, -3, $next));
         $this->assertSame(4, $next);
-        $this->assertSame('jà', grapheme_extract('déjà', 2, GRAPHEME_EXTR_MAXCHARS, -3));
+        $this->assertSame('jà', grapheme_extract('déjà', 2, \GRAPHEME_EXTR_MAXCHARS, -3));
     }
 
     /**
@@ -89,7 +102,13 @@ class GraphemeTest extends TestCase
     {
         $c = 'déjà';
 
-        if (\PHP_VERSION_ID >= 50418 && \PHP_VERSION_ID !== 50500) {
+        $this->assertSame('jà', grapheme_substr($c, -2, null));
+
+        if (\PHP_VERSION_ID >= 80000) {
+            $this->assertSame('jà', grapheme_substr($c, -2, 3));
+            $this->assertSame('', grapheme_substr($c, -1, 0));
+            $this->assertSame('', grapheme_substr($c, 1, -4));
+        } else {
             // See http://bugs.php.net/62759 and 55562
             $this->assertSame('jà', grapheme_substr($c, -2, 3));
             $this->assertSame('', grapheme_substr($c, -1, 0));
@@ -100,8 +119,32 @@ class GraphemeTest extends TestCase
         $this->assertSame('jà', grapheme_substr($c, -2));
         $this->assertSame('j', grapheme_substr($c, -2, -1));
         $this->assertSame('', grapheme_substr($c, -2, -2));
-        $this->assertFalse(grapheme_substr($c, 5, 0));
-        $this->assertFalse(grapheme_substr($c, -5, 0));
+    }
+
+    /**
+     * @covers \Symfony\Polyfill\Intl\Grapheme\Grapheme::grapheme_substr
+     * @requires PHP < 8
+     */
+    public function testGraphemeSubstrReturnsFalsePrePHP8()
+    {
+        $c = 'déjà';
+        $this->assertFalse(grapheme_substr($c, 5, 1));
+        $this->assertFalse(grapheme_substr($c, -5, 1));
+        $this->assertFalse(grapheme_substr($c, -42, 1));
+        $this->assertFalse(grapheme_substr($c, 42, 5));
+    }
+
+    /**
+     * @covers \Symfony\Polyfill\Intl\Grapheme\Grapheme::grapheme_substr
+     * @requires PHP 8
+     */
+    public function testGraphemeSubstrReturnsEmptyPostPHP8()
+    {
+        $c = 'déjà';
+        $this->assertSame('', grapheme_substr($c, 5, 1));
+        $this->assertSame('d', grapheme_substr($c, -5, 1));
+        $this->assertSame('d', grapheme_substr($c, -42, 1));
+        $this->assertSame('', grapheme_substr($c, 42, 5));
     }
 
     /**
@@ -113,24 +156,26 @@ class GraphemeTest extends TestCase
      */
     public function testGraphemeStrpos()
     {
-        $this->assertFalse(grapheme_strpos('abc', ''));
+        if (80000 > \PHP_VERSION_ID) {
+            $this->assertFalse(grapheme_strpos('abc', ''));
+        } else {
+            $this->assertSame(0, grapheme_strpos('abc', ''));
+        }
         $this->assertFalse(grapheme_strpos('abc', 'd'));
         $this->assertFalse(grapheme_strpos('abc', 'a', 3));
-        if (\PHP_VERSION_ID < 50535 || (50600 <= \PHP_VERSION_ID && \PHP_VERSION_ID < 50621) || (70000 <= \PHP_VERSION_ID && \PHP_VERSION_ID < 70006)) {
-            $this->assertSame(0, grapheme_strpos('abc', 'a', -1));
-        } else {
-            $this->assertFalse(grapheme_strpos('abc', 'a', -1));
-        }
+        $this->assertFalse(grapheme_strpos('abc', 'a', -1));
         $this->assertSame(1, grapheme_strpos('한국어', '국'));
         $this->assertSame(3, grapheme_stripos('DÉJÀ', 'à'));
-        $this->assertFalse(grapheme_strrpos('한국어', ''));
+        if (80000 > \PHP_VERSION_ID) {
+            $this->assertFalse(grapheme_strrpos('한국어', ''));
+        } else {
+            $this->assertSame(3, grapheme_strrpos('한국어', ''));
+        }
         $this->assertSame(1, grapheme_strrpos('한국어', '국'));
         $this->assertSame(3, grapheme_strripos('DÉJÀ', 'à'));
     }
 
     /**
-     * @requires PHP 7.1
-     *
      * @covers \Symfony\Polyfill\Intl\Grapheme\Grapheme::grapheme_strpos
      * @covers \Symfony\Polyfill\Intl\Grapheme\Grapheme::grapheme_stripos
      * @covers \Symfony\Polyfill\Intl\Grapheme\Grapheme::grapheme_strrpos
@@ -160,27 +205,4 @@ class GraphemeTest extends TestCase
         $this->assertSame('국어', grapheme_strstr('한국어', '국'));
         $this->assertSame('ÉJÀ', grapheme_stristr('DÉJÀ', 'é'));
     }
-
-    public function testGraphemeBugs()
-    {
-        if (\PHP_VERSION_ID < 50418 || \PHP_VERSION_ID === 50500) {
-            // see https://bugs.php.net/61860
-            $this->markTestSkipped('PHP 5.4.18 or 5.5.1 is required.');
-        }
-        $this->assertSame(16, grapheme_stripos('der Straße nach Paris', 'Paris'));
-        $this->assertSame('Paris', grapheme_stristr('der Straße nach Paris', 'Paris'));
-    }
-
-    public function setExpectedException($exception, $message = '', $code = null)
-    {
-        if (!class_exists('PHPUnit\Framework\Error\Notice')) {
-            $exception = str_replace('PHPUnit\\Framework\\Error\\', 'PHPUnit_Framework_Error_', $exception);
-        }
-        if (method_exists($this, 'expectException')) {
-            $this->expectException($exception);
-            $this->expectExceptionMessage($message);
-        } else {
-            parent::setExpectedException($exception, $message, $code);
-        }
-    }
 }
