@@ -28,17 +28,41 @@ class MbstringTest extends TestCase
      */
     public function testStubs()
     {
-        $this->assertFalse(@mb_substitute_character('?'));
         $this->assertTrue(mb_substitute_character('none'));
         $this->assertSame('none', mb_substitute_character());
 
         $this->assertContains('UTF-8', mb_list_encodings());
 
         $this->assertTrue(mb_internal_encoding('utf8'));
-        $this->assertFalse(@mb_internal_encoding('no-no'));
         $this->assertSame('UTF-8', mb_internal_encoding());
     }
 
+    /**
+     * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_substitute_character
+     */
+    public function testSubstituteCharacterWithInvalidCharacter()
+    {
+        if (80000 <= \PHP_VERSION_ID) {
+            $this->expectException(\ValueError::class);
+            $this->expectExceptionMessage('Argument #1 ($substitute_character) must be "none", "long", "entity" or a valid codepoint');
+        }
+
+        $this->assertFalse(@mb_substitute_character('?'));
+    }
+
+    /**
+     * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_substitute_character
+     */
+    public function testInternalEncodingWithInvalidEncoding()
+    {
+        if (80000 <= \PHP_VERSION_ID) {
+            $this->expectException(\ValueError::class);
+            $this->expectExceptionMessage('Argument #1 ($encoding) must be a valid encoding, "no-no" given');
+        }
+
+        $this->assertFalse(@mb_internal_encoding('no-no'));
+    }
+
     /**
      * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_convert_encoding
      */
@@ -50,7 +74,7 @@ class MbstringTest extends TestCase
         $this->assertSame('déjà', mb_convert_encoding(base64_encode('déjà'), 'Utf-8', 'Base64'));
         $this->assertSame('déjà', mb_convert_encoding('d&eacute;j&#224;', 'Utf-8', 'Html-entities'));
         $this->assertSame('déjà', mb_convert_encoding(utf8_decode('déjà'), 'Utf-8', 'ASCII,ISO-2022-JP,UTF-8,ISO-8859-1'));
-        $this->assertSame('déjà', mb_convert_encoding(utf8_decode('déjà'), 'Utf-8', array('ASCII', 'ISO-2022-JP', 'UTF-8', 'ISO-8859-1')));
+        $this->assertSame('déjà', mb_convert_encoding(utf8_decode('déjà'), 'Utf-8', ['ASCII', 'ISO-2022-JP', 'UTF-8', 'ISO-8859-1']));
     }
 
     /**
@@ -58,11 +82,12 @@ class MbstringTest extends TestCase
      */
     public function testDecodeNumericEntity()
     {
-        $convmap = array(0x80, 0x10ffff, 0x1, 0x1fffff);
-        $this->assertNull(@mb_decode_numericentity(new \stdClass(), $convmap, 'UTF-8'));
-        $this->assertFalse(@mb_decode_numericentity('déjà', new \stdClass(), 'UTF-8'));
-        $this->assertFalse(@mb_decode_numericentity('déjà', array(), 'UTF-8'));
-        $this->assertEmpty(@mb_decode_numericentity('déjà', $convmap, new \stdClass()));  // PHPUnit returns null.
+        $convmap = [0x80, 0x10ffff, 0x1, 0x1fffff];
+        if (80000 > \PHP_VERSION_ID) {
+            $this->assertFalse(@mb_decode_numericentity('déjà', [], 'UTF-8'));
+        } else {
+            $this->assertSame('déjà', mb_decode_numericentity('déjà', [], 'UTF-8'));
+        }
 
         $this->assertSame('', mb_decode_numericentity('', $convmap, 'UTF-8'));
         $iso = 'déjà &amp; &225; &#E1; &#XE1; &#e1; &#Xe1;';
@@ -70,12 +95,10 @@ class MbstringTest extends TestCase
 
         $this->assertSame('déjà &#0; à á', mb_decode_numericentity('déjà &#0; &#225; &#226;', $convmap, 'UTF-8'));
         $this->assertSame('déjà &#0; à á', mb_decode_numericentity('déjà &#0; &#0000225; &#0000226;', $convmap, 'UTF-8'));
-        if (PHP_VERSION > 54000) {
-            $this->assertSame('déjà &#0; à á', mb_decode_numericentity('déjà &#0; &#xe1; &#xe2;', $convmap, 'UTF-8'));
-            $this->assertSame('déjà &#0; à á', mb_decode_numericentity('déjà &#0; &#x0000e1; &#x0000e2;', $convmap, 'UTF-8'));
-            $this->assertSame('déjà &#0; à á', mb_decode_numericentity('déjà &#0; &#xE1; &#xE2;', $convmap, 'UTF-8'));
-            $this->assertSame('déjà &#0; à á', mb_decode_numericentity('déjà &#0; &#x0000E1; &#x0000E2;', $convmap, 'UTF-8'));
-        }
+        $this->assertSame('déjà &#0; à á', mb_decode_numericentity('déjà &#0; &#xe1; &#xe2;', $convmap, 'UTF-8'));
+        $this->assertSame('déjà &#0; à á', mb_decode_numericentity('déjà &#0; &#x0000e1; &#x0000e2;', $convmap, 'UTF-8'));
+        $this->assertSame('déjà &#0; à á', mb_decode_numericentity('déjà &#0; &#xE1; &#xE2;', $convmap, 'UTF-8'));
+        $this->assertSame('déjà &#0; à á', mb_decode_numericentity('déjà &#0; &#x0000E1; &#x0000E2;', $convmap, 'UTF-8'));
         --$convmap[2];
         $this->assertSame('déjà &#0; á â', mb_decode_numericentity('déjà &#0; &#225; &#226;', $convmap, 'UTF-8'));
         --$convmap[2];
@@ -84,25 +107,41 @@ class MbstringTest extends TestCase
         $bogusDecEntities = 'déjà &#0; &#225;&#225; &#&#225&#225 &#225 &#225t';
         $this->assertSame('déjà &#0; ââ &#&#225â â ât', mb_decode_numericentity($bogusDecEntities, $convmap, 'UTF-8'));
 
-        if (PHP_VERSION > 54000) {
-            $bogusHexEntities = 'déjà &#x0; &#xe1;&#xe1; &#xe1 &#xe1t &#xE1 &#xE1t';
-            $this->assertSame('déjà &#x0; ââ â ât â ât', mb_decode_numericentity($bogusHexEntities, $convmap, 'UTF-8'));
-        }
+        $bogusHexEntities = 'déjà &#x0; &#xe1;&#xe1; &#xe1 &#xe1t &#xE1 &#xE1t';
+        $this->assertSame('déjà &#x0; ââ â ât â ât', mb_decode_numericentity($bogusHexEntities, $convmap, 'UTF-8'));
 
         array_push($convmap, 0x1f600, 0x1f64f, -0x1f602, 0x0);
         $this->assertSame('déjà 😂 â ã', mb_decode_numericentity('déjà &#0; &#225; &#226;', $convmap, 'UTF-8'));
 
-        $convmap = array(0x100, 0x10ffff, 0x0, 0x1fffff);
+        $convmap = [0x100, 0x10ffff, 0x0, 0x1fffff];
         $this->assertSame("\xFE", mb_decode_numericentity('&#351;', $convmap, 'ISO-8859-9'));
     }
 
+    /**
+     * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_decode_numericentity
+     * @requires PHP < 8
+     */
+    public function testDecodeNumericEntityWithInvalidTypes()
+    {
+        $convmap = [0x80, 0x10ffff, 0x1, 0x1fffff];
+
+        $this->assertNull(@mb_decode_numericentity(new \stdClass(), $convmap, 'UTF-8'));
+        $this->assertFalse(@mb_decode_numericentity('déjà', new \stdClass(), 'UTF-8'));
+        $this->assertEmpty(@mb_decode_numericentity('déjà', $convmap, new \stdClass()));  // PHPUnit returns null.
+    }
+
     /**
      * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_decode_numericentity
      */
     public function testDecodeNumericEntityWarnsOnInvalidInputType()
     {
-        $this->setExpectedException('PHPUnit\Framework\Error\Warning', 'expects parameter 1 to be string');
-        mb_decode_numericentity(new \stdClass(), array(0x0, 0x10ffff, 0x0, 0x1fffff), 'UTF-8');
+        if (80000 > \PHP_VERSION_ID) {
+            $this->expectWarning();
+            $this->expectWarningMessage('expects parameter 1 to be string');
+        } else {
+            $this->expectException(\TypeError::class);
+        }
+        mb_decode_numericentity(new \stdClass(), [0x0, 0x10ffff, 0x0, 0x1fffff], 'UTF-8');
     }
 
     /**
@@ -110,8 +149,13 @@ class MbstringTest extends TestCase
      */
     public function testDecodeNumericEntityWarnsOnInvalidEncodingType()
     {
-        $this->setExpectedException('PHPUnit\Framework\Error\Warning', 'expects parameter 3 to be string');
-        mb_decode_numericentity('déjà', array(0x0, 0x10ffff, 0x0, 0x1fffff), new \stdClass());
+        if (80000 > \PHP_VERSION_ID) {
+            $this->expectWarning();
+            $this->expectWarningMessage('expects parameter 3 to be string');
+        } else {
+            $this->expectException(\TypeError::class);
+        }
+        mb_decode_numericentity('déjà', [0x0, 0x10ffff, 0x0, 0x1fffff], new \stdClass());
     }
 
     /**
@@ -119,12 +163,12 @@ class MbstringTest extends TestCase
      */
     public function testEncodeNumericEntity()
     {
-        $convmap = array(0x80, 0x10ffff, 0x1, 0x1fffff);
-        $this->assertNull(@mb_encode_numericentity(new \stdClass(), $convmap, 'UTF-8'));
-        $this->assertFalse(@mb_encode_numericentity('déjà', new \stdClass(), 'UTF-8'));
-        $this->assertFalse(@mb_encode_numericentity('déjà', array(), 'UTF-8'));
-        $this->assertNull(@mb_encode_numericentity('déjà', $convmap, new \stdClass()));
-        $this->assertNull(@mb_encode_numericentity('déjà', $convmap, 'UTF-8', new \stdClass()));
+        $convmap = [0x80, 0x10ffff, 0x1, 0x1fffff];
+        if (80000 > \PHP_VERSION_ID) {
+            $this->assertFalse(@mb_encode_numericentity('déjà', [], 'UTF-8'));
+        } else {
+            $this->assertSame('déjà', mb_encode_numericentity('déjà', [], 'UTF-8'));
+        }
 
         $this->assertSame('', mb_encode_numericentity('', $convmap, 'UTF-8'));
         $iso = 'abc &amp; &#225; &#xe1; &#xE1;';
@@ -140,25 +184,42 @@ class MbstringTest extends TestCase
         array_push($convmap, 0x0, 0x1f, 0x1f602, 0x1fffff);
         $this->assertSame('&#128514; &#96;', mb_encode_numericentity("\x00 a", $convmap, 'UTF-8'));
 
-        $convmap = array(0x100, 0x10ffff, 0x0, 0x1fffff);
+        $convmap = [0x100, 0x10ffff, 0x0, 0x1fffff];
         $this->assertSame('&#351;', mb_encode_numericentity("\xFE", $convmap, 'ISO-8859-9'));
 
-        if (PHP_VERSION > 54000) {
-            $this->assertSame('&#351;', mb_encode_numericentity("\xFE", $convmap, 'ISO-8859-9', false));
-            $this->assertSame('&#x15F;', mb_encode_numericentity("\xFE", $convmap, 'ISO-8859-9', true));
-        }
+        $this->assertSame('&#351;', mb_encode_numericentity("\xFE", $convmap, 'ISO-8859-9', false));
+        $this->assertSame('&#x15F;', mb_encode_numericentity("\xFE", $convmap, 'ISO-8859-9', true));
 
         // U+1F602 FACE WITH TEARS OF JOY is F0 9F 98 82 in UTF-8. ISO-8859-9 leaves 7F-9F undefined.
         $this->assertSame("abc &#287;\x9F\x98\x82", mb_encode_numericentity('abc 😂', $convmap, 'ISO-8859-9'));
     }
 
+    /**
+     * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_encode_numericentity
+     * @requires PHP < 8
+     */
+    public function testEncodeNumericEntityWithInvalidTypes()
+    {
+        $convmap = [0x80, 0x10ffff, 0x1, 0x1fffff];
+
+        $this->assertNull(@mb_encode_numericentity(new \stdClass(), $convmap, 'UTF-8'));
+        $this->assertFalse(@mb_encode_numericentity('déjà', new \stdClass(), 'UTF-8'));
+        $this->assertNull(@mb_encode_numericentity('déjà', $convmap, new \stdClass()));
+        $this->assertNull(@mb_encode_numericentity('déjà', $convmap, 'UTF-8', new \stdClass()));
+    }
+
     /**
      * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_decode_numericentity
      */
     public function testEncodeNumericEntityWarnsOnInvalidInputType()
     {
-        $this->setExpectedException('PHPUnit\Framework\Error\Warning', 'expects parameter 1 to be string');
-        mb_encode_numericentity(new \stdClass(), array(0x0, 0x10ffff, 0x0, 0x1fffff), 'UTF-8');
+        if (80000 > \PHP_VERSION_ID) {
+            $this->expectWarning();
+            $this->expectWarningMessage('expects parameter 1 to be string');
+        } else {
+            $this->expectException(\TypeError::class);
+        }
+        mb_encode_numericentity(new \stdClass(), [0x0, 0x10ffff, 0x0, 0x1fffff], 'UTF-8');
     }
 
     /**
@@ -166,18 +227,27 @@ class MbstringTest extends TestCase
      */
     public function testEncodeNumericEntityWarnsOnInvalidEncodingType()
     {
-        $this->setExpectedException('PHPUnit\Framework\Error\Warning', 'expects parameter 3 to be string');
-        mb_encode_numericentity('déjà', array(0x0, 0x10ffff, 0x0, 0x1fffff), new \stdClass());
+        if (80000 > \PHP_VERSION_ID) {
+            $this->expectWarning();
+            $this->expectWarningMessage('expects parameter 3 to be string');
+        } else {
+            $this->expectException(\TypeError::class);
+        }
+        mb_encode_numericentity('déjà', [0x0, 0x10ffff, 0x0, 0x1fffff], new \stdClass());
     }
 
     /**
-     * @requires PHP 5.4
      * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_decode_numericentity
      */
     public function testEncodeNumericEntityWarnsOnInvalidIsHexType()
     {
-        $this->setExpectedException('PHPUnit\Framework\Error\Warning', 'expects parameter 4 to be bool');
-        mb_encode_numericentity('déjà', array(0x0, 0x10ffff, 0x0, 0x1fffff), 'UTF-8', new \stdClass());
+        if (80000 > \PHP_VERSION_ID) {
+            $this->expectWarning();
+            $this->expectWarningMessage('expects parameter 4 to be bool');
+        } else {
+            $this->expectException(\TypeError::class);
+        }
+        mb_encode_numericentity('déjà', [0x0, 0x10ffff, 0x0, 0x1fffff], 'UTF-8', new \stdClass());
     }
 
     /**
@@ -187,16 +257,13 @@ class MbstringTest extends TestCase
      */
     public function testStrCase()
     {
-        $this->assertSame(\PHP_VERSION_ID >= 70300 ? 'i̇' : 'i', \mb_strtolower('İ'));
+        $this->assertSame(\PHP_VERSION_ID >= 70300 ? 'i̇' : 'i', mb_strtolower('İ'));
         $this->assertSame('déjà σσς iiıi', p::mb_strtolower('DÉJÀ Σσς İIıi'));
         $this->assertSame('DÉJÀ ΣΣΣ İIII', mb_strtoupper('Déjà Σσς İIıi'));
-        if (PCRE_VERSION >= '8.10') {
-            $this->assertSame('Déjà Σσσ Iı Ii İi', p::mb_convert_case('DÉJÀ ΣΣΣ ıı iI İİ', MB_CASE_TITLE));
-        }
-        if (\PHP_VERSION_ID >= 70000) {
-            // Native iconv() is buggy before PHP 7
-            $this->assertSame('ab', str_replace('?', '', mb_strtolower(urldecode('a%A1%C0b'))));
+        if (\PCRE_VERSION >= '8.10') {
+            $this->assertSame('Déjà Σσσ Iı Ii İi', p::mb_convert_case('DÉJÀ ΣΣΣ ıı iI İİ', \MB_CASE_TITLE));
         }
+        $this->assertSame('ab', str_replace('?', '', mb_strtolower(urldecode('a%A1%C0b'))));
     }
 
     /**
@@ -222,7 +289,7 @@ class MbstringTest extends TestCase
                         continue 2;
                     }
             }
-            $this->assertSame(mb_convert_case('a'.\chr($i).'b', MB_CASE_TITLE, 'UTF-8'), p::mb_convert_case('a'.\chr($i).'b', MB_CASE_TITLE, 'UTF-8'), 'Title case for char 0x'.dechex($i));
+            $this->assertSame(mb_convert_case('a'.\chr($i).'b', \MB_CASE_TITLE, 'UTF-8'), p::mb_convert_case('a'.\chr($i).'b', \MB_CASE_TITLE, 'UTF-8'), 'Title case for char 0x'.dechex($i));
         }
     }
 
@@ -274,13 +341,21 @@ class MbstringTest extends TestCase
      */
     public function testStrpos()
     {
-        $this->assertFalse(@mb_strpos('abc', ''));
+        if (80000 > \PHP_VERSION_ID) {
+            $this->assertFalse(@mb_strpos('abc', ''));
+        } else {
+            $this->assertSame(0, mb_strpos('abc', ''));
+        }
         $this->assertFalse(@mb_strpos('abc', 'a', -1));
         $this->assertFalse(mb_strpos('abc', 'd'));
         $this->assertFalse(mb_strpos('abc', 'a', 3));
         $this->assertSame(1, mb_strpos('한국어', '국'));
         $this->assertSame(3, mb_stripos('DÉJÀ', 'à'));
-        $this->assertFalse(mb_strrpos('한국어', ''));
+        if (80000 > \PHP_VERSION_ID) {
+            $this->assertFalse(mb_strrpos('한국어', ''));
+        } else {
+            $this->assertSame(3, mb_strrpos('한국어', ''));
+        }
         $this->assertSame(1, mb_strrpos('한국어', '국'));
         $this->assertSame(3, mb_strripos('DÉJÀ', 'à'));
         $this->assertSame(1, mb_stripos('aςσb', 'ΣΣ'));
@@ -291,11 +366,13 @@ class MbstringTest extends TestCase
 
     /**
      * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_strpos
+     * @requires PHP < 8
      */
     public function testStrposEmptyDelimiter()
     {
         mb_strpos('abc', 'a');
-        $this->setExpectedException('PHPUnit\Framework\Error\Warning', 'Empty delimiter');
+        $this->expectWarning();
+        $this->expectWarningMessage('Empty delimiter');
         mb_strpos('abc', '');
     }
 
@@ -305,12 +382,7 @@ class MbstringTest extends TestCase
     public function testStrposNegativeOffset()
     {
         mb_strpos('abc', 'a');
-        if (\PHP_VERSION_ID >= 70100) {
-            $this->assertFalse(mb_strpos('abc', 'a', -1));
-        } else {
-            $this->setExpectedException('PHPUnit\Framework\Error\Warning', 'Offset not contained in string');
-            mb_strpos('abc', 'a', -1);
-        }
+        $this->assertFalse(mb_strpos('abc', 'a', -1));
     }
 
     /**
@@ -318,19 +390,36 @@ class MbstringTest extends TestCase
      */
     public function testStrSplit()
     {
-        $this->assertSame(array('H', "\r", "\n", 'W'), mb_str_split("H\r\nW", 1));
-        $this->assertSame(array('Hell', "o\nWo", 'rld!'), mb_str_split("Hello\nWorld!", 4));
-        $this->assertSame(array('한', '국', '어'), mb_str_split('한국어'));
-        $this->assertSame(array('по', 'бе', 'да'), mb_str_split('победа', 2));
-        $this->assertSame(array('źre', 'bię'), mb_str_split('źrebię', 3));
-        $this->assertSame(array('źr', 'ebi', 'ę'), mb_str_split('źrebię', 3, 'ASCII'));
-        $this->assertSame(array('alpha', 'bet'), mb_str_split('alphabet', 5));
-        $this->assertSame(array('e', '́', '💩', '𐍈'), mb_str_split('é💩𐍈', 1, 'UTF-8'));
-        $this->assertSame(array(), mb_str_split('', 1, 'UTF-8'));
-        $this->assertFalse(@mb_str_split('победа', 0));
-        $this->assertNull(@mb_str_split(array(), 0));
+        $this->assertSame(['H', "\r", "\n", 'W'], mb_str_split("H\r\nW", 1));
+        $this->assertSame(['Hell', "o\nWo", 'rld!'], mb_str_split("Hello\nWorld!", 4));
+        $this->assertSame(['한', '국', '어'], mb_str_split('한국어'));
+        $this->assertSame(['по', 'бе', 'да'], mb_str_split('победа', 2));
+        $this->assertSame(['źre', 'bię'], mb_str_split('źrebię', 3));
+        $this->assertSame(['źr', 'ebi', 'ę'], mb_str_split('źrebię', 3, 'ASCII'));
+        $this->assertSame(['alpha', 'bet'], mb_str_split('alphabet', 5));
+        $this->assertSame(['e', '́', '💩', '𐍈'], mb_str_split('é💩𐍈', 1, 'UTF-8'));
+        $this->assertSame([], mb_str_split('', 1, 'UTF-8'));
+
+        if (80000 > \PHP_VERSION_ID) {
+            $this->assertNull(@mb_str_split([], 0));
+        }
+    }
+
+    /**
+     * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_str_split
+     */
+    public function testStrSplitWithInvalidLength()
+    {
+        if (80000 > \PHP_VERSION_ID) {
+            $this->assertFalse(@mb_str_split('победа', 0));
+
+            $this->expectWarning();
+            $this->expectWarningMessage('The length of each segment must be greater than zero');
+        } else {
+            $this->expectException(\ValueError::class);
+            $this->expectExceptionMessage('Argument #2 ($length) must be greater than 0');
+        }
 
-        $this->setExpectedException('PHPUnit\Framework\Error\Warning', 'The length of each segment must be greater than zero');
         mb_str_split('победа', 0);
     }
 
@@ -349,12 +438,16 @@ class MbstringTest extends TestCase
         $this->assertSame('ÉJÀDÉJÀ', mb_stristr('DÉJÀDÉJÀ', 'é'));
         $this->assertSame('ςσb', mb_stristr('aςσb', 'ΣΣ'));
         $this->assertSame('éjà', mb_strrchr('déjàdéjà', 'é'));
+        $this->assertSame('éjà', mb_strrchr('déjàdéjà', 'é', false, 'ASCII'));
+        $this->assertFalse(mb_strrchr('déjàdéjà', 'X', false, 'ASCII'));
         $this->assertSame('ÉJÀ', mb_strrichr('DÉJÀDÉJÀ', 'é'));
 
         $this->assertSame('d', mb_strstr('déjàdéjà', 'é', true));
         $this->assertSame('D', mb_stristr('DÉJÀDÉJÀ', 'é', true));
         $this->assertSame('a', mb_stristr('aςσb', 'ΣΣ', true));
         $this->assertSame('déjàd', mb_strrchr('déjàdéjà', 'é', true));
+        $this->assertSame('déjàd', mb_strrchr('déjàdéjà', 'é', true, 'ASCII'));
+        $this->assertFalse(mb_strrchr('déjàdéjà', 'X', true, 'ASCII'));
         $this->assertSame('DÉJÀD', mb_strrichr('DÉJÀDÉJÀ', 'é', true));
         $this->assertSame('Paris', mb_stristr('der Straße nach Paris', 'Paris'));
     }
@@ -378,8 +471,8 @@ class MbstringTest extends TestCase
         $this->assertTrue(mb_detect_order('ASCII, UTF-8'));
         $this->assertSame('ASCII', mb_detect_encoding('abc'));
         $this->assertSame('UTF-8', mb_detect_encoding('abc', 'UTF8, ASCII'));
-        $this->assertSame('ISO-8859-1', mb_detect_encoding("\xE9", array('UTF-8', 'ASCII', 'ISO-8859-1'), true));
-        $this->assertFalse(mb_detect_encoding("\xE9", array('UTF-8', 'ASCII', 'Windows-1252'), true));
+        $this->assertSame('ISO-8859-1', mb_detect_encoding("\xE9", ['UTF-8', 'ASCII', 'ISO-8859-1'], true));
+        $this->assertFalse(mb_detect_encoding("\xE9", ['UTF-8', 'ASCII', 'Windows-1252'], true));
     }
 
     /**
@@ -388,8 +481,8 @@ class MbstringTest extends TestCase
     public function testDetectOrder()
     {
         $this->assertTrue(mb_detect_order('ASCII, UTF-8'));
-        $this->assertSame(array('ASCII', 'UTF-8'), mb_detect_order());
-        $this->assertTrue(mb_detect_order(array('ASCII', 'UTF-8')));
+        $this->assertSame(['ASCII', 'UTF-8'], mb_detect_order());
+        $this->assertTrue(mb_detect_order(['ASCII', 'UTF-8']));
     }
 
     /**
@@ -399,16 +492,28 @@ class MbstringTest extends TestCase
     {
         $this->assertTrue(mb_language('UNI'));
         $this->assertSame('uni', mb_language());
-        $this->assertFalse(@mb_language('ABC'));
         $this->assertTrue(mb_language('neutral'));
     }
 
+    /**
+     * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_language
+     */
+    public function testLanguageWithInvalidLanguage()
+    {
+        if (80000 <= \PHP_VERSION_ID) {
+            $this->expectException(\ValueError::class);
+            $this->expectExceptionMessage('Argument #1 ($language) must be a valid language, "ABC" given');
+        }
+
+        $this->assertFalse(@mb_language('ABC'));
+    }
+
     /**
      * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_encoding_aliases
      */
     public function testEncodingAliases()
     {
-        $this->assertSame(array('utf8'), mb_encoding_aliases('UTF-8'));
+        $this->assertSame(['utf8'], mb_encoding_aliases('UTF-8'));
         $this->assertFalse(p::mb_encoding_aliases('ASCII'));
     }
 
@@ -442,22 +547,9 @@ class MbstringTest extends TestCase
 
     public function testScrub()
     {
-        $subst = \mb_substitute_character();
-        \mb_substitute_character('none');
+        $subst = mb_substitute_character();
+        mb_substitute_character('none');
         $this->assertSame('ab', mb_scrub("a\xE9b"));
-        \mb_substitute_character($subst);
-    }
-
-    public function setExpectedException($exception, $message = '', $code = null)
-    {
-        if (!class_exists('PHPUnit\Framework\Error\Notice')) {
-            $exception = str_replace('PHPUnit\\Framework\\Error\\', 'PHPUnit_Framework_Error_', $exception);
-        }
-        if (method_exists($this, 'expectException')) {
-            $this->expectException($exception);
-            $this->expectExceptionMessage($message);
-        } else {
-            parent::setExpectedException($exception, $message, $code);
-        }
+        mb_substitute_character($subst);
     }
 }
