@@ -21,8 +21,8 @@ class Php73Test extends TestCase
 {
     public function testIsCountable()
     {
-        $this->assertTrue(is_countable(array(1, 2, '3')));
-        $this->assertTrue(is_countable(new \ArrayIterator(array('foo', 'bar', 'baz'))));
+        $this->assertTrue(is_countable([1, 2, '3']));
+        $this->assertTrue(is_countable(new \ArrayIterator(['foo', 'bar', 'baz'])));
         $this->assertTrue(is_countable(new \ArrayIterator()));
         $this->assertTrue(is_countable(new \SimpleXMLElement('<foo><bar/><bar/><bar/></foo>')));
         $this->assertFalse(is_countable(new \stdClass()));
@@ -33,9 +33,6 @@ class Php73Test extends TestCase
         }
     }
 
-    /**
-     * @requires PHP 5.5
-     */
     public function testIsCountableForGenerator()
     {
         require_once 'generator.php';
@@ -46,11 +43,11 @@ class Php73Test extends TestCase
     public function testHardwareTimeAsNumType()
     {
         $hrtime = hrtime(true);
-        if (PHP_INT_SIZE === 4) {
-            $this->assertInternalType('float', $hrtime);
+        if (\PHP_INT_SIZE === 4) {
+            $this->assertIsFloat($hrtime);
             $this->assertEquals(floor($hrtime), $hrtime);
         } else {
-            $this->assertInternalType('int', $hrtime);
+            $this->assertIsInt($hrtime);
         }
     }
 
@@ -60,7 +57,7 @@ class Php73Test extends TestCase
         usleep(100000);
         $hrtime2 = hrtime(true);
 
-        if (PHP_INT_SIZE === 4) {
+        if (\PHP_INT_SIZE === 4) {
             $this->assertGreaterThanOrEqual(90000000.0, $hrtime2 - $hrtime);
         } else {
             $this->assertGreaterThanOrEqual(100000000.0, $hrtime2 - $hrtime);
@@ -70,10 +67,10 @@ class Php73Test extends TestCase
     public function testHardwareTimeAsArrayType()
     {
         $hrtime = hrtime();
-        $this->assertInternalType('array', $hrtime);
+        $this->assertIsArray($hrtime);
         $this->assertCount(2, $hrtime);
-        $this->assertInternalType('int', $hrtime[0]);
-        $this->assertInternalType('int', $hrtime[1]);
+        $this->assertIsInt($hrtime[0]);
+        $this->assertIsInt($hrtime[1]);
     }
 
     public function testHardwareTimeAsArrayNanos()
@@ -106,7 +103,7 @@ class Php73Test extends TestCase
 
     public function testArrayKeyFirstVariation()
     {
-        $array = array(1, 2, 3, 4, 5, 6, 7, 8, 9);
+        $array = [1, 2, 3, 4, 5, 6, 7, 8, 9];
 
         $this->assertSame(1, current($array));
         $this->assertSame(2, next($array));
@@ -124,7 +121,7 @@ class Php73Test extends TestCase
 
     public function testArrayKeyLastVariation()
     {
-        $array = array(1, 2, 3, 4, 5, 6, 7, 8, 9);
+        $array = [1, 2, 3, 4, 5, 6, 7, 8, 9];
 
         $this->assertSame(1, current($array));
         $this->assertSame(2, next($array));
@@ -134,39 +131,39 @@ class Php73Test extends TestCase
 
     public function arrayKeyFirstDataProvider()
     {
-        return array(
-            array(null,  array()),
-            array(0,     array(1, 2, 3, 4, 5, 6, 7, 8, 9)),
-            array(0,     array('One', '_Two', 'Three', 'Four', 'Five')),
-            array(0,     array(6, 'six', 7, 'seven', 8, 'eight', 9, 'nine')),
-            array('a',   array('a' => 'aaa', 'A' => 'AAA', 'c' => 'ccc', 'd' => 'ddd', 'e' => 'eee')),
-            array(1,     array('1' => 'one', '2' => 'two', '3' => 'three', '4' => 'four', '5' => 'five')),
-            array(1,     array(1 => 'one', 2 => 'two', 3 => 7, 4 => 'four', 5 => 'five')),
-            array('f',   array('f' => 'fff', '1' => 'one', 4 => 6, '' => 'blank', 2.4 => 'float', 'F' => 'FFF', 'blank' => '', 3.7 => 3.7, 5.4 => 7, 6 => 8.6, '5' => 'Five', '4name' => 'jonny', 'a' => null, null => 3)),
-            array(0,     array(12, 'name', 'age', '45')),
-            array(0,     array(array('oNe', 'tWo', 4), array(10, 20, 30, 40, 50), array())),
-            array('one', array('one' => 1, 'one' => 2, 'three' => 3, 3, 4, 3 => 33, 4 => 44, 5, 6, 5.4 => 54, 5.7 => 57, '5.4' => 554, '5.7' => 557)),
-            array(0,     array('foo')),
-            array(1,     array(1 => '42')),
-        );
+        return [
+            [null,  []],
+            [0,     [1, 2, 3, 4, 5, 6, 7, 8, 9]],
+            [0,     ['One', '_Two', 'Three', 'Four', 'Five']],
+            [0,     [6, 'six', 7, 'seven', 8, 'eight', 9, 'nine']],
+            ['a',   ['a' => 'aaa', 'A' => 'AAA', 'c' => 'ccc', 'd' => 'ddd', 'e' => 'eee']],
+            [1,     ['1' => 'one', '2' => 'two', '3' => 'three', '4' => 'four', '5' => 'five']],
+            [1,     [1 => 'one', 2 => 'two', 3 => 7, 4 => 'four', 5 => 'five']],
+            ['f',   ['f' => 'fff', '1' => 'one', 4 => 6, '' => 'blank', 2.4 => 'float', 'F' => 'FFF', 'blank' => '', 3.7 => 3.7, 5.4 => 7, 6 => 8.6, '5' => 'Five', '4name' => 'jonny', 'a' => null, null => 3]],
+            [0,     [12, 'name', 'age', '45']],
+            [0,     [['oNe', 'tWo', 4], [10, 20, 30, 40, 50], []]],
+            ['one', ['one' => 1, 'one' => 2, 'three' => 3, 3, 4, 3 => 33, 4 => 44, 5, 6, 5.4 => 54, 5.7 => 57, '5.4' => 554, '5.7' => 557]],
+            [0,     ['foo']],
+            [1,     [1 => '42']],
+        ];
     }
 
     public function arrayKeyLastDataProvider()
     {
-        return array(
-            array(null,  array()),
-            array(8,     array(1, 2, 3, 4, 5, 6, 7, 8, 9)),
-            array(4,     array('One', '_Two', 'Three', 'Four', 'Five')),
-            array(7,     array(6, 'six', 7, 'seven', 8, 'eight', 9, 'nine')),
-            array('e',   array('a' => 'aaa', 'A' => 'AAA', 'c' => 'ccc', 'd' => 'ddd', 'e' => 'eee')),
-            array(5,     array('1' => 'one', '2' => 'two', '3' => 'three', '4' => 'four', '5' => 'five')),
-            array(5,     array(1 => 'one', 2 => 'two', 3 => 7, 4 => 'four', 5 => 'five')),
-            array('a',   array('f' => 'fff', '1' => 'one', 4 => 6, '' => 'blank', 2.4 => 'float', 'F' => 'FFF', 'blank' => '', 3.7 => 3.7, 5.4 => 7, 6 => 8.6, '5' => 'Five', '4name' => 'jonny', 'a' => null, null => 3)),
-            array(3,     array(12, 'name', 'age', '45')),
-            array(2,     array(array('oNe', 'tWo', 4), array(10, 20, 30, 40, 50), array())),
-            array('5.7', array('one' => 1, 'one' => 2, 'three' => 3, 3, 4, 3 => 33, 4 => 44, 5, 6, 5.4 => 54, 5.7 => 57, '5.4' => 554, '5.7' => 557)),
-            array(0,     array('foo')),
-            array(1,     array(1 => '42')),
-        );
+        return [
+            [null,  []],
+            [8,     [1, 2, 3, 4, 5, 6, 7, 8, 9]],
+            [4,     ['One', '_Two', 'Three', 'Four', 'Five']],
+            [7,     [6, 'six', 7, 'seven', 8, 'eight', 9, 'nine']],
+            ['e',   ['a' => 'aaa', 'A' => 'AAA', 'c' => 'ccc', 'd' => 'ddd', 'e' => 'eee']],
+            [5,     ['1' => 'one', '2' => 'two', '3' => 'three', '4' => 'four', '5' => 'five']],
+            [5,     [1 => 'one', 2 => 'two', 3 => 7, 4 => 'four', 5 => 'five']],
+            ['a',   ['f' => 'fff', '1' => 'one', 4 => 6, '' => 'blank', 2.4 => 'float', 'F' => 'FFF', 'blank' => '', 3.7 => 3.7, 5.4 => 7, 6 => 8.6, '5' => 'Five', '4name' => 'jonny', 'a' => null, null => 3]],
+            [3,     [12, 'name', 'age', '45']],
+            [2,     [['oNe', 'tWo', 4], [10, 20, 30, 40, 50], []]],
+            ['5.7', ['one' => 1, 'one' => 2, 'three' => 3, 3, 4, 3 => 33, 4 => 44, 5, 6, 5.4 => 54, 5.7 => 57, '5.4' => 554, '5.7' => 557]],
+            [0,     ['foo']],
+            [1,     [1 => '42']],
+        ];
     }
 }
